@@ -63,16 +63,18 @@ var searchData=
   ['mpechannelassigner_60',['MPEChannelAssigner',['../classMPEChannelAssigner.html',1,'']]],
   ['mpechannelremapper_61',['MPEChannelRemapper',['../classMPEChannelRemapper.html',1,'']]],
   ['mpeinstrument_62',['MPEInstrument',['../classMPEInstrument.html',1,'']]],
-  ['mpemessages_63',['MPEMessages',['../classMPEMessages.html',1,'']]],
-  ['mpenote_64',['MPENote',['../structMPENote.html',1,'']]],
-  ['mpesynthesiser_65',['MPESynthesiser',['../classMPESynthesiser.html',1,'']]],
-  ['mpesynthesiserbase_66',['MPESynthesiserBase',['../structMPESynthesiserBase.html',1,'']]],
-  ['mpesynthesiservoice_67',['MPESynthesiserVoice',['../classMPESynthesiserVoice.html',1,'']]],
-  ['mpevalue_68',['MPEValue',['../classMPEValue.html',1,'']]],
-  ['mpezonelayout_69',['MPEZoneLayout',['../classMPEZoneLayout.html',1,'']]],
-  ['multichoicepropertycomponent_70',['MultiChoicePropertyComponent',['../classMultiChoicePropertyComponent.html',1,'']]],
-  ['multidocumentpanel_71',['MultiDocumentPanel',['../classMultiDocumentPanel.html',1,'']]],
-  ['multidocumentpanelwindow_72',['MultiDocumentPanelWindow',['../classMultiDocumentPanelWindow.html',1,'']]],
-  ['multiplicative_73',['Multiplicative',['../structValueSmoothingTypes_1_1Multiplicative.html',1,'ValueSmoothingTypes']]],
-  ['multitimer_74',['MultiTimer',['../classMultiTimer.html',1,'']]]
+  ['mpekeyboardcomponent_63',['MPEKeyboardComponent',['../classMPEKeyboardComponent.html',1,'']]],
+  ['mpemessages_64',['MPEMessages',['../classMPEMessages.html',1,'']]],
+  ['mpenote_65',['MPENote',['../structMPENote.html',1,'']]],
+  ['mpesynthesiser_66',['MPESynthesiser',['../classMPESynthesiser.html',1,'']]],
+  ['mpesynthesiserbase_67',['MPESynthesiserBase',['../structMPESynthesiserBase.html',1,'']]],
+  ['mpesynthesiservoice_68',['MPESynthesiserVoice',['../classMPESynthesiserVoice.html',1,'']]],
+  ['mpevalue_69',['MPEValue',['../classMPEValue.html',1,'']]],
+  ['mpezone_70',['MPEZone',['../structMPEZone.html',1,'']]],
+  ['mpezonelayout_71',['MPEZoneLayout',['../classMPEZoneLayout.html',1,'']]],
+  ['multichoicepropertycomponent_72',['MultiChoicePropertyComponent',['../classMultiChoicePropertyComponent.html',1,'']]],
+  ['multidocumentpanel_73',['MultiDocumentPanel',['../classMultiDocumentPanel.html',1,'']]],
+  ['multidocumentpanelwindow_74',['MultiDocumentPanelWindow',['../classMultiDocumentPanelWindow.html',1,'']]],
+  ['multiplicative_75',['Multiplicative',['../structValueSmoothingTypes_1_1Multiplicative.html',1,'ValueSmoothingTypes']]],
+  ['multitimer_76',['MultiTimer',['../classMultiTimer.html',1,'']]]
 ];
