@@ -3,5 +3,7 @@ var searchData=
   ['action_0',['Action',['../structPushNotifications_1_1Settings.html#a255d01e017e3594e8b4705254f9256bb',1,'PushNotifications::Settings']]],
   ['alerticontype_1',['AlertIconType',['../classAlertWindow.html#ac772713875db1d4038dd03f82d399df5',1,'AlertWindow']]],
   ['audioblocktype_2',['AudioBlockType',['../structdsp_1_1ProcessContextReplacing.html#aaa293a78b2efd11aec17ba8f67b5f466',1,'dsp::ProcessContextReplacing::AudioBlockType()'],['../structdsp_1_1ProcessContextNonReplacing.html#a7cfdcc50ccc9e8bf85169600c0cbac08',1,'dsp::ProcessContextNonReplacing::AudioBlockType()']]],
-  ['audiosamplebuffer_3',['AudioSampleBuffer',['../group__juce__audio__basics-buffers.html#gab339ebab0d3b10c91c0d47c8fd2e50d2',1,'juce_AudioSampleBuffer.h']]]
+  ['audiocomponentinstance_3',['AudioComponentInstance',['../group__juce__audio__processors-utilities.html#ga8d76a4b29adb5f5b39318dd91162b8f4',1,'juce_ExtensionsVisitor.h']]],
+  ['audiosamplebuffer_4',['AudioSampleBuffer',['../group__juce__audio__basics-buffers.html#gab339ebab0d3b10c91c0d47c8fd2e50d2',1,'juce_AudioSampleBuffer.h']]],
+  ['audiounit_5',['AudioUnit',['../group__juce__audio__processors-utilities.html#ga55e0e3a99e12b3f8e10f9125dc891709',1,'juce_ExtensionsVisitor.h']]]
 ];
